@@ -43,6 +43,12 @@ class CreateDBLinkRequest(RpcRequest):
 	def set_SourceDBName(self,SourceDBName):
 		self.add_query_param('SourceDBName',SourceDBName)
 
+	def get_ClientToken(self):
+		return self.get_query_params().get('ClientToken')
+
+	def set_ClientToken(self,ClientToken):
+		self.add_query_param('ClientToken',ClientToken)
+
 	def get_TargetDBName(self):
 		return self.get_query_params().get('TargetDBName')
 
