@@ -89,10 +89,4 @@ class ModifyBackupPolicyRequest(RpcRequest):
 		return self.get_query_params().get('PreferredBackupTime')
 
 	def set_PreferredBackupTime(self,PreferredBackupTime):
-		self.add_query_param('PreferredBackupTime',PreferredBackupTime)
-
-	def get_BackupRetentionPeriod(self):
-		return self.get_query_params().get('BackupRetentionPeriod')
-
-	def set_BackupRetentionPeriod(self,BackupRetentionPeriod):
-		self.add_query_param('BackupRetentionPeriod',BackupRetentionPeriod)
\ No newline at end of file
+		self.add_query_param('PreferredBackupTime',PreferredBackupTime)
\ No newline at end of file
